
# $Id: Event.pm,v 1.1 1998/12/18 22:23:04 gtaylor Exp $
# Autobuse module implementing a reportable event object

# A reportable event has:
# 
# hostname -> a hostname, the source of the attack/probe/whatever
# hostaddr -> an addres, the source of the attack/probe/whatever
# text -> a human-readable text description of the attack/probe/whatever
# key -> a "key" which uniquely identifies this attack by
#        dest/type (but not by time or source). 


package Autobuse::Event;

use Autobuse::Common;

# ctor takes name/addr, key, descriptive text, and log line
sub new {
    my $type = $_[0];		# will be Autobuse::Event...
    my $hostaddr = $_[1];

    # Canonify address/name
    my $hostname = lookup_ip($hostaddr);
    $hostaddr = lookup_host($hostaddr) if ($hostaddr =~ /^[\.\d]+$/);

    # build object
    my $this = {'hostname' => $hostname,
		'hostaddr' => $hostaddr,
		'key' => $_[2],
		'text' => $_[3],
		'log' => $_[4]};
    bless $this;
    return $this;
}

sub get_desc {
    return $_[0]->{'text'};
}

sub get_key {
    return $_[0]->{'key'};
}

sub get_log {
    return $_[0]->{'log'};
}

sub get_addr {
    return $_[0]->{'hostaddr'};
}

sub dump {
    my $this = $_[0];
    print STDERR 
	"Event: (key '",
	$this->get_key(),
	"') ",
	format_ip($this->get_addr()),
	": ", 
	$this->get_desc(),
	"\n";
}

1;
